<?php
/**
* Project:     Morgdkp2 eqdkp plus plug-in
* License:     Creative Commons - Attribution-Noncommercial-Share Alike 3.0 Unported
* Link:    http://creativecommons.org/licenses/by-nc-sa/3.0/
* -----------------------------------------------------------------------
* Began:       2013
* -----------------------------------------------------------------------
* @author      BlueWarlord
* @copyright   2013-
* Based upon the EQdkp-Plus epgpimport plug-in and Morgalm's original morgdkp 2 plug-in for eqkdp plus 0.6
*/


// EQdkp required files/vars
define('EQDKP_INC', true);
define('IN_ADMIN', true);
$eqdkp_root_path = './../../../';
include_once($eqdkp_root_path.'common.php');

class morgdkp2_import extends page_generic {
	private $parser, $pdl;
	
	public static function __shortcuts() {
		$shortcuts = array('user', 'in', 'tpl', 'core', 'pm', 'config', 'jquery', 'html'
		);
		return array_merge(parent::$shortcuts, $shortcuts);
	}  
	
	public function __construct() {
		$this->user->check_auth('a_morgdkp2_import');
		
		$handler = array(
			'insert'  => array('process' => 'insert_log')
		);
		parent::__construct(false, $handler);
		$this->pdl = registry::register('plus_debug_logger'); 
		$this->process();
	}
	
	public function insert_log(){
		if ($_POST['log'] != ''){
			include_once('../includes/morgdkp2_parser.class.php');
			
			$this->parser = register('morgdkp2_parser');
			
			$parseresult = $this->parser->parse($_POST['log']);
			if (! $parseresult) {
				//error
				$this->core->message($this->user->lang('morgdkp2_import_parse_error'), $this->user->lang('error'), 'red');
			} else {
				$this->core->message($this->user->lang('morgdkp2_import_parse_success'), $this->user->lang('success'), 'green');  
	
				// Set the DKP change information if available
				$dkpChangeHTML = $this->generateDKPChangeHTML();
				if (sizeof($dkpChangeHTML) > 0) {
					$this->tpl->assign_vars(array(
						'DKPChanged' => $dkpChangeHTML,
						'S_DKPChanged' => true,
					));
				} else {
					$this->tpl->assign_vars(array(
					'S_DKPChanged' => false,
					));
				}
		
				// Set the alias information if available
				$aliasHTML = $this->generateAliasHTML();
				if (sizeof($aliasHTML) > 0) {
					$this->tpl->assign_vars(array(
						'ALIAS' => $aliasHTML,
						'S_ALIAS' => true,
					));
				} else {
					$this->tpl->assign_vars(array(
					'S_ALIAS' => false,
					));
				}
			
				// Set the raid information if available
				if (isset($_SESSION['RAID'])) {
					$this->tpl->assign_vars(array(
						'RAIDS' => $this->generateRaidOverviewHTML(),
						'S_RAIDS' => true,
					));
				} else {
					$this->tpl->assign_vars(array(
					'S_RAIDS' => false,
					));
				}
			
				$this->tpl->assign_vars(array(
					'TITLE' => $this->user->lang('morgimport_import_preview'),
					'INPUT_INSTRUCTIONS' => $this->user->lang('morgimport_input_preview_instructions'),
					'ENTER_FINAL_DATA' => $this->user->lang('Enter_final_data')
				));
			
				$this->core->set_vars(array(
					'page_title'        => $this->user->lang('morgimport_import_preview'),
					'template_path'     => $this->pm->get_data('morgdkp2', 'template_path'),
					'template_file'     => 'admin/import_preview.html',
					'display'           => true,
					));
				}
		}      
	}
	
	public function display($messages=array(), $blnImportFinished=false) {
		//fetch itempools
		$itempools = $this->pdh->aget('itempool', 'name', 0, array($this->pdh->get('itempool', 'id_list')));
		asort($itempools);
	
		$this->tpl->assign_vars(array(
			'ITEMPOOLS'      => $this->html->DropDown('itempool', $itempools, false),
			'TITLE' => $this->user->lang('morgimport_import'). ' v3.3',
			'INPUT_INSTRUCTIONS' => $this->user->lang('morgimport_input_instructions'),
		));
	
		$this->core->set_vars(array(
			'page_title'        => $this->user->lang('morgimport_import'). ' v3.3',
			'template_path'     => $this->pm->get_data('morgdkp2', 'template_path'),
			'template_file'     => 'admin/import.html',
			'display'           => true,
		));
	}
  
	private function generateDKPChangeHTML() {
		//global $parser;
		$result = "";
		//$parser = register('morgdkp2_parser');
		$Switches = $this->parser->getSwitches();
		if (isset($Switches['dkpchange'])) { 
			$result .="<u><b>DKP adjustments to be added to Database:</u></b><br><br>";
			$result .="<table border='1' cellpadding='12'>";
			$result .=" <tr><td><strong>Member </strong></td><td><strong>Adjustment </strong></td><td><strong>Database </strong></td><td><strong>Pool </strong></td><td><strong>Event/Note </strong></td></tr>";
			foreach ($needchanged as $i => $changes) {
				if ($changes['addtype'] == "Group" ) {
					$changevalue[$i]['members'] = implode("\n", $changes['members']);
					$result .= "<tr><td><textarea style='width: 150px; height: 100px;' name='changevalue[".$i."][members]'>".$changevalue[$i]['members']."</textarea>";
					$result .= "</td><td><input name='changevalue[".$i."][value]' size='3' value='".$changes['value']."'></td><td>";
					$result .= $changes['eqdkp']."</td><td>".$changes['pool']."</td><td>".$changes['event']."</td></tr>";
				} else {
					$result .= "<tr><td><input name='changevalue[".$i."][members]' size='20' value='".$changes['name']."'></td><td>";
					$result .= "<input name='changevalue[".$i."][value]' size='3' value='".$changes['value']."'></td><td>".$changes['eqdkp'];
					$result .= "</td><td>".$changes['pool']. "</td><td>".$changes['event']."</td></tr>";
				}
			} // End for-each
		}
		return $result;
	} // End of generateDKPChangeHTML()
  
	private function generateAliasHTML() {
		$result = "";
		$Switches = $this->parser->Switches;
		$newalts = $this->parser->newalts;
		$this->pdl->log("morgdkp2", 'Switches array:'.$this->pdl->format_array($Switches));
		
		if (isset($Switches['alias'])) {
			$result .= "<u><b>Alias changes to Database:</u></b><br><br>";
			$result .= "<table border='1' cellpadding='12'>";
			$result .= "<tr><td><strong>Alt </strong></td><td><strong>Main </strong></td><td><strong>Database </strong></td><td><strong>Pool </strong></td><td><strong>Action </strong></td></tr>";
			foreach ($newalts as $i => $aliases) {
				$result .= "<tr><td><input name='altfield[".$i."][alt]' value='".$aliases['alt']."'></td><td>".$aliases['main']."</td><td>";
				$result .= $aliases['eqdkp']."</td><td>".$aliases['pool']."</td><td>".$aliases['action']."</td></tr>";
			}
			$result .= "</table><hr>";
		} 
		return $result;
	} // End of generateAliasHTML()
  
	private function generateRaidOverviewHTML () {
		$result = "";
		$RAID = $_SESSION['RAID'];
		
		foreach ($RAID as $i => $raiddata) {       
			$result .= "<b>Database: </b>&nbsp;&nbsp;".$raiddata['eqdkp'] . "<br><br>";
			$result .= "<b>Pool: </b>&nbsp;&nbsp;".$raiddata['pool']. "<br><br>";
			$result .= "<b>Zone</b>&nbsp;&nbsp;<input name='raidfield[". $i . "][zone]' value='". htmlentities($raiddata['zone'],ENT_QUOTES)."'>";
			$result .= "&nbsp;&nbsp;&nbsp;&nbsp;Use 0-sum DKP&nbsp;&nbsp;<input type='checkbox' name=raidfield[". $i ."][zsum]'><br><br>";
		
			foreach ($raiddata['events'] as $event => $eventdata) { 
				$result .= "<b>Event</b>&nbsp;&nbsp;<input name='raidfield[".$i."][events][".$event."][name]' size='40' value='".htmlentities($eventdata['name'], ENT_QUOTES)."'><br>";
				$result .= "<b>Note</b>&nbsp;&nbsp;&nbsp;&nbsp;<input name='raidfield[".$i."][events][". $event . "][note]' size='40' value='".htmlentities($eventdata['note'],ENT_QUOTES) ."'><br>";
				$result .= "<b>Value</b>&nbsp;&nbsp;<input name='raidfield[".$i. "][events][".$event. "][value]' size='3' value='". $eventdata['value'] . "'><br>";
				$result .= "<b>Time</b>&nbsp;&nbsp;&nbsp;". strftime("%Y/%m/%d %H:%M:%S", $eventdata['time']). "<br><br>";
				$raidfield[$i]['events'][$event]['attendees'] = implode("\n", $eventdata['attendees']);
			
				$result .= "<b>Attendees</b><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
				$result .= "<textarea style='width: 150px; height: 300px;' name=raidfield[".$i."][events][".$event. "][attendees]'>".$raidfield[$i]['events'][$event]['attendees']."</textarea><br>";
		
				if (isset($raiddata['loot'][$eventdata['index']]) && $raiddata['loot'][$eventdata['index']]) {
					foreach ($raiddata['loot'][$eventdata['index']] as $loot => $lootdata) { 
						$eventname = $eventdata['index'];
						$result .= "<br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
						$result .= "<input name='raidfield[".$i."][loot][".$eventname."][".$loot."][ItemName]' size='30' value='".htmlentities($lootdata['ItemName'],ENT_QUOTES)."'><br>";
						$result .= "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
						$result .= "<input name='raidfield[".$i."][loot][".$eventname."][".$loot."][Costs]' size='30' value='".$lootdata['Costs']."'><br>";
						$result .= "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
						$result .= "<input name='raidfield[".$i."][loot][".$eventname."][".$loot."][Player]' size='30' value='".$lootdata['Player']."'><br>";
					}
				} 
				if (isset($raiddata['loot']['Trash mob']) && $raiddata['loot']['Trash mob'] and $eventdata['trash'] == 2) {
					$result .= "<br>";
					foreach ($raiddata['loot']['Trash mob'] as $tloot => $trashdata) {
						$result .= "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
						$result .= "<input name='raidfield[".$i."][loot][Trash mob][".$tloot."][ItemName]' size='30' value='".htmlentities($trashdata['ItemName'],ENT_QUOTES)."'><br>";
						$result .= "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
						$result .= "<input name='raidfield[".$i."][loot][Trash mob][".$tloot."][Costs]' size='30' value='".$trashdata['Costs']. "'><br>";
						$result .= "&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;";
						$result .= "<input name='raidfield[".$i."][loot][Trash mob][".$tloot."][Player]' size='30' value='".$trashdata['Player']."'><br><br>";
					}
				}
				$result .= "<br><hr>";
			}
		$result .= "<hr>";
		}    
		return $result;
	}
		
}
//if(version_compare(PHP_VERSION, '5.3.0', '<')) registry::add_const('short_epgp_import', epgp_import::__shortcuts());
// Make sure to register this import class, as only then it gets actually called.
registry::register('morgdkp2_import');

?>

